@@ -15,7 +15,32 @@ App::gh::Command::PullReq::Send - pull request of current branch.
 
 =head1 USAGE
 
-    $ gh pullreq send ([branch])
+    $ gh pullreq send ([base branch]) ([owner]/[repo])
+
+Base branch: the branch you fork from.
+
+Owner/Repo:  the repository you fork from.
+
+Example:
+
+    $ gh pullreq send
+
+    $ gh pullreq send master c9s/App-gh
+
+=head1 API
+
+API Spec is from L<http://develop.github.com/p/pulls.html>
+
+    pull[base] - A String of the branch or commit SHA that you want your
+        changes to be pulled to.
+
+    pull[head] - A String of the branch or commit SHA of your changes.
+        Typically this will be a branch. If the branch is in a fork of the original
+        repository, specify the username first: "my-user:some-branch".
+
+    pull[title] - The String title of the Pull Request (and the related Issue).
+
+    pull[body] - The String body of the Pull Request.
 
 =cut
 
@@ -56,11 +81,19 @@ sub run {
         die;
     }
 
-    my $remote_branch = shift||'master';
-    my $remote = $self->get_remote();
+    my $remote_branch = shift ||'master';
+    my $base          = shift;
+    my ($user,$repo,$uri_type);
+    if( $base ) {
+        ($user,$repo) = split m{[/:]},$base;
+
+    } else {
+        my $remote = $self->get_remote();
+        die "Remote not found\n." unless $remote;
+        ($user, $repo, $uri_type ) = parse_uri( $remote->{url} );
+    }
+
 
-    die "Remote not found\n." unless $remote;
-    my ( $user, $repo, $uri_type ) = parse_uri( $remote->{url} );
 
     my $gh_id = App::gh->config->github_id;
     my $gh_token = App::gh->config->github_token;
@@ -68,6 +101,7 @@ sub run {
         die "Github authtoken not found. Can not send pull request.\n";
     }
 
+
     my $local_repo = Git->repository();
     open my $fh, '<', $local_repo->wc_path()."/.git/HEAD";
     my $ref = <$fh>;
@@ -76,13 +110,22 @@ sub run {
 
     my ($branch) = ( $ref =~ m{ref:\s\S+?/\S+?/(\S+)} );
 
-    my $f = File::Temp->new(SUFFIX => ".mkd");
+    my $f = File::Temp->new(SUFFIX => ".md");
     my $t = stat($f->filename)->mtime;
+
+    open $fh , ">" , $f->filename;
+    print $fh "Title\n";
+    print $fh "Body (markdown format)\n";
+    close $fh;
+
+    # launch editor
     system $ENV{EDITOR}, $f->filename;
+
     if ($t == stat($f->filename)->mtime) {
         _info "No changes. Pull request was not sent.";
         return;
     }
+
     open $fh, '<', $f->filename;
     my $content = do { local $/; <$fh> };
     close $fh;
@@ -96,10 +139,10 @@ sub run {
     }
 
     _info "Sending pull request for $branch...";
+    # XXX: make arguments into hash format
     my $data = App::gh->api->pullreq_send($user, $repo, $branch, $remote_branch, $title, $body);
 
     _info "Sent: " . $data->{pull}->{html_url};
 }
 
-
 1;
